/*
 * Copyright 2001 Andreas Mohr
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#ifndef __SETUPAPI_PRIVATE_H
#define __SETUPAPI_PRIVATE_H

#define COPYFILEDLGORD	1000
#define SOURCESTRORD	500
#define DESTSTRORD	501
#define PROGRESSORD	502


#define REG_INSTALLEDFILES "System\\CurrentControlSet\\Control\\InstalledFiles"
#define REGPART_RENAME "\\Rename"
#define REG_VERSIONCONFLICT "Software\\Microsoft\\VersionConflictManager"

static inline WCHAR *strdupAtoW( const char *str )
{
    WCHAR *ret = NULL;
    if (str)
    {
        DWORD len = MultiByteToWideChar( CP_ACP, 0, str, -1, NULL, 0 );
        if ((ret = HeapAlloc( GetProcessHeap(), 0, len * sizeof(WCHAR) )))
            MultiByteToWideChar( CP_ACP, 0, str, -1, ret, len );
    }
    return ret;
}

/* string substitutions */

struct inf_file;
extern const WCHAR *DIRID_get_string( int dirid );
extern unsigned int PARSER_string_substA( struct inf_file *file, const WCHAR *text,
                                          char *buffer, unsigned int size );
extern unsigned int PARSER_string_substW( struct inf_file *file, const WCHAR *text,
                                          WCHAR *buffer, unsigned int size );
extern const WCHAR *PARSER_get_inf_filename( HINF hinf );
extern WCHAR *PARSER_get_src_root( HINF hinf );
extern WCHAR *PARSER_get_dest_dir( INFCONTEXT *context );

/* support for Ascii queue callback functions */

struct callback_WtoA_context
{
    void               *orig_context;
    PSP_FILE_CALLBACK_A orig_handler;
};

UINT CALLBACK QUEUE_callback_WtoA( void *context, UINT notification, UINT_PTR, UINT_PTR );

/* from msvcrt/sys/stat.h */
#define _S_IWRITE 0x0080
#define _S_IREAD  0x0100

typedef BOOL WINAPI *device_registry_fn (
        LPVOID  node,
        DWORD   Property,
        PDWORD  PropertyRegDataType,
        PBYTE   PropertyBuffer,
        DWORD   PropertyBufferSize,
        PDWORD  RequiredSize,
        BOOL    unicode);

typedef struct devnode_tag{
    WCHAR   enumerator[20];
    WCHAR   devicePath[MAX_PATH*2];
    DWORD   flags;
    GUID    guid;
    WCHAR   vendor[20];
    DWORD   iVendor;
    WCHAR   product[20];
    DWORD   iProduct;
    WCHAR   revision[5];
    WCHAR   serial[50];
    WCHAR   devicetype[20];
    WCHAR   deviceId[MAX_PATH];
    LPWSTR  hardwareid;
    LPVOID  reserved;
    device_registry_fn *registry_fn;
} devnode;

typedef struct devinfo_struct_tag {
/* from the winehq structure */
    DWORD magic;
    GUID ClassGuid;
    HWND hwndParent;
/* our Crossover structure */
    DWORD flags;
    BOOL  unicode;
    int count;
    devnode *devices;
} devinfo_struct;

/* some custome device properties */
#define SPDRP_DEVICE_PATH (SPDRP_MAXIMUM_PROPERTY + 1)
#define SPDRP_DEVICEINST (SPDRP_MAXIMUM_PROPERTY + 2)
#define SPDRP_DEVICE_ID (SPDRP_MAXIMUM_PROPERTY + 3)

UINT USB_GetDeviceDevs(devinfo_struct *devinfo, CONST GUID *class,
                       LPCSTR enumstr);

extern OSVERSIONINFOW OsVersionInfo;

extern BOOL create_fake_dll( const WCHAR *name, const WCHAR *source );

#endif /* __SETUPAPI_PRIVATE_H */
